package cn.com.ty.lift.business.maintenance.controller;

import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.maintenance.dao.entity.model.BatchMaintenancePlanRequest;
import cn.com.ty.lift.business.maintenance.dao.entity.model.MaintenancePlanRequest;
import cn.com.ty.lift.business.maintenance.dao.entity.model.UpdateMaintenancePlanReq;
import cn.com.ty.lift.business.maintenance.service.MaintenancePlanService;
import cn.com.ty.lift.common.base.ExportRequest;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.util.ObjectUtil;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author bieao
 * @date 2019/12/12
 * @description 维保管理控制层
 */
@RestController
@RequestMapping("maintenance")
public class MaintenanceController {

    @Resource
    private MaintenancePlanService maintenancePlanService;

    /**
     * @param request 电梯列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 制定维保计划
     * @date 2019/12/16 2:36 PM
     */
    @PostMapping("generate/plan")
    public RestResponse generatePlan(@RequestBody MaintenancePlanRequest request) {
        boolean result = maintenancePlanService.insertBatch(request);
        if (result) {
            return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.add.success"));
        } else {
            return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.add.fail"));
        }
    }

    /**
     * @param request 电梯列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 修改维保计划
     * @date 2019/12/16 2:36 PM
     */
    @PostMapping("modify/plan")
    public RestResponse modifyPlan(@RequestBody UpdateMaintenancePlanReq request) {
        boolean result = maintenancePlanService.modifyPlan(request);
        if (result) {
            return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.modify.success"));
        } else {
            return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.fail"));
        }
    }

    /**
     * @param request ids 维保计划id列表
     * @return 是否成功
     * @description 清空维保计划
     * @date 2019/12/17 3:14 PM
     */
    @PostMapping("batch/clean")
    public RestResponse deleteByIds(@RequestBody BatchMaintenancePlanRequest request) {
        List<Long> ids = request.getIds();
        if (ObjectUtil.isEmpty(ids)) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_PARAM, MessageUtils.get("msg.param.empty"));
        }
        boolean result = maintenancePlanService.deleteByIds(request);
        if (result) {
            return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.modify.success"));
        } else {
            return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.fail"));
        }
    }

    /**
     * @param request 导出项目数据列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 导出维保计划
     * @date 2019/12/19 11:28 AM
     */
    @PostMapping("export/plan")
    public void export(@RequestBody ExportRequest request) {
        maintenancePlanService.export(request);
    }
}
